summaryrefslogtreecommitdiffstats
path: root/templates/annotated/menuapp2.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/menuapp2.py')
-rw-r--r--templates/annotated/menuapp2.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/templates/annotated/menuapp2.py b/templates/annotated/menuapp2.py
index 1924eef..6447d1c 100644
--- a/templates/annotated/menuapp2.py
+++ b/templates/annotated/menuapp2.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n
+from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData, i18n
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction
STATUSBAR_LEFT = 1
@@ -147,7 +147,7 @@ class MainWin (KMainWindow):
self.specialAction.plug (editMenu)
self.menuBar ().insertItem (i18n ("&Edit"), editMenu)
# Uses the info from KAboutData (specified below)
# to construct the "About" box in the Help menu
helpMenu = self.helpMenu ("")
@@ -227,8 +227,8 @@ class MainWin (KMainWindow):
description = "A basic application template"
version = "1.0"
-aboutData = KAboutData ("", "",\
- version, description, KAboutData.License_GPL,\
+aboutData = TDEAboutData ("", "",\
+ version, description, TDEAboutData.License_GPL,\
"(C) 2003 whoever the author is")
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
@@ -147,7 +147,7 @@ class MainWin (KMainWindow):
self.specialAction.plug (editMenu)
self.menuBar ().insertItem (i18n ("&Edit"), editMenu)
- # Uses the info from KAboutData (specified below)
+ # Uses the info from TDEAboutData (specified below)
# to construct the "About" box in the Help menu
helpMenu = self.helpMenu ("")